"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/filesystem.ts
var filesystem_exports = {};
__export(filesystem_exports, {
  exists: () => exists,
  findMonoRepoPackages: () => findMonoRepoPackages,
  findMonoRepoRoot: () => findMonoRepoRoot,
  projectRoot: () => projectRoot
});
module.exports = __toCommonJS(filesystem_exports);

// src/filesystem/project-root.ts
var import_node_path = require("path");
var import_find_up = require("find-up");
async function projectRoot(fallbackToCwd = false, cwd) {
  const packageJsonPath = await (0, import_find_up.findUp)("package.json", { cwd });
  if (!packageJsonPath) {
    if (fallbackToCwd) {
      return process.cwd();
    }
    throw new Error("Unable to find project root (no package.json found)");
  }
  return (0, import_node_path.dirname)(packageJsonPath);
}

// src/filesystem/exists.ts
var import_promises = require("fs/promises");
async function exists(path) {
  try {
    await (0, import_promises.stat)(path);
    return true;
  } catch {
    return false;
  }
}

// src/filesystem/mono-repo.ts
var import_promises2 = require("fs/promises");
var import_node_path2 = require("path");

// src/json.ts
function tryParseJson(value, defaultValue = null) {
  try {
    const parsed = JSON.parse(value);
    if (parsed === void 0 || parsed === null) {
      return defaultValue;
    }
    return parsed;
  } catch (err) {
    return defaultValue;
  }
}

// src/filesystem/mono-repo.ts
var import_find_up2 = require("find-up");
var import_glob = require("glob");
async function findMonoRepoRoot(startDir) {
  const lockFilePath = await (0, import_find_up2.findUp)(["package-lock.json", "yarn.lock", "pnpm-lock.yaml", "bun.lockb", "bun.lock"], {
    cwd: startDir
  });
  if (lockFilePath) {
    const packageJsonPath = (0, import_node_path2.join)((0, import_node_path2.dirname)(lockFilePath), "package.json");
    const hasWorkSpaces = await packageJsonHasWorkspaces(packageJsonPath);
    return hasWorkSpaces ? (0, import_node_path2.dirname)(lockFilePath) : null;
  }
  let currentDir = startDir;
  while (currentDir !== "/") {
    const packageJsonPath = (0, import_node_path2.join)(currentDir, "package.json");
    if (await packageJsonHasWorkspaces(packageJsonPath)) {
      return currentDir;
    }
    const parentDir = (0, import_node_path2.dirname)(currentDir);
    if (parentDir === currentDir) {
      break;
    }
    currentDir = parentDir;
  }
  return null;
}
async function findMonoRepoPackages(projectDir) {
  try {
    const monoRepoRoot = await findMonoRepoRoot(projectDir);
    if (!monoRepoRoot) {
      return [projectDir];
    }
    const packageJsonPath = (0, import_node_path2.join)(monoRepoRoot, "package.json");
    const packageJson = tryParseJson(await (0, import_promises2.readFile)(packageJsonPath, "utf-8"));
    const workspaces = packageJson?.workspaces ?? [];
    const packagePaths = await Promise.all(
      workspaces.map(async (workspace) => {
        const matches = await (0, import_glob.glob)((0, import_node_path2.join)(monoRepoRoot, workspace, "package.json"));
        return matches.map((match) => (0, import_node_path2.join)(match, ".."));
      })
    );
    const allPaths = packagePaths.flat();
    return allPaths.length === 0 ? [projectDir] : [monoRepoRoot, ...allPaths];
  } catch (error) {
    return [projectDir];
  }
}
async function packageJsonHasWorkspaces(packageJsonPath) {
  if (await exists(packageJsonPath)) {
    const packageJson = tryParseJson(await (0, import_promises2.readFile)(packageJsonPath, "utf-8"));
    if (packageJson?.workspaces && Array.isArray(packageJson?.workspaces) && packageJson?.workspaces.length > 0) {
      return true;
    }
  }
  return false;
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  exists,
  findMonoRepoPackages,
  findMonoRepoRoot,
  projectRoot
});
//# sourceMappingURL=filesystem.cjs.map